Choose Opera - Spreading Opera goodness

My Opera

- Sign up
- Log in

# Choose Opera

Spreading Opera goodness

## LastPass is now available as an Opera extension

By Espen André Øverdahl. Wednesday, 24. November, 18:35

lastpass, extension

Good news, everybody! By popular request, LastPass is now available as an Opera extension.

LastPass is a free online password manager and Form Filler that makes your web browsing easier and more secure. You can import from most major password storage vendors (such as RoboForm, 1Password, KeePass, Password Safe, MyPasswordSafe, Sxipper, TurboPasswords, and Passpack) and export too.

42 comments

## Abakus winners

By Aleksander Aas. Wednesday, 24. November, 12:29

html5, contest

We are happy to announce the winners of the The NTNU HTML5 Challenge. After reviewing both the quality of the code of and the responses we have our winner.

Our winner is Dag Einar Monsen with GanjaFarmer, a community favorite with high quality code. Dag Einar will get to choose what Opera office around the world he wants to complete a summer internship in 2011.

The runner-ups Samer Nakfour (Weather5) and Samuel Wejéus (Tweetiebirds) will be offered a summer internship in the Opera offices in Norway or Sweden.

We would like to thank all participants for the cool applications they have submitted. You all made this competition amazing!

25 comments

## Opera 11 beta gets some Wired love

By Espen André Øverdahl. Wednesday, 24. November, 10:05

webmonkey, wired, opera 11

Webmonkey is Wired's resource site for web site developers including how-to guides, code libraries, server technologies and authoring resources. We were stoked this morning when we woke up to great praise of the Opera 11 beta we released yesterday:

"[...] Opera 11 is shaping up to be a great release both for Opera fans and those who use other browsers, which, if history is any guide, will soon be mimicking Opera’s lead."

24 comments

## Opera Mobile 10.1 for Nokia smartphones

By Espen André Øverdahl. Wednesday, 24. November, 09:36

symbian, nokia, smartphone, opera mobile

Hold onto your hats, Nokia smartphone owners. Today we unleashed the final version of Opera Mobile 10.1 for Symbian/Series 60 phones, with significantly faster JavaScript performance for a speedy browsing experience.

Opera Mobile 10.1 is available for smartphones based on Symbian^3, and Symbian S60 3rd and 5th editions. Opera Mobile is free to download from m.opera.com. Read more about Opera Mobile at www.opera.com/mobile.

41 comments

## Opera 11 wallpapers

By Espen André Øverdahl. Tuesday, 23. November, 12:48

wallpaper, opera 11

The Opera design team has just released three different wallpapers to celebrate the beta launch.

11 comments

## Opera 11 beta media coverage

By Espen André Øverdahl. Tuesday, 23. November, 10:10

beta, opera 11, media coverage

Alright, here we go again. Another release, another batch of media coverage! If you come across an interesting article which is not covered here - please let us know as a comment below and we'll update this list.

As always, we encourage everyone to participate in discussions about Opera in articles (especially if there's any trolling or wrong facts/rumors being spread).

Remember to reload (CTRL/Command+R) this post for the latest news coverage about Opera!

Website: | Article: | Comments:
Inquirer | Opera releases 11 beta with tab stacking | No comments yet. Will you be the first?
Techtree.com | Opera 11 Beta comes with Tab Stacking Feature | No discussion yet.
CNET (blog) | Opera goes to 11 with an extensions API | No comments yet. Be the first?
PC Pro | Opera 11 brings improved tab management | Be the first to comment this article.
TechRadar UK | Hands on: Opera 11 review (Beta) | 1 comment in the discussion area.
Techconnect Magazine | Opera 11 beta 1 available, includes tab stacking, extensions and more | None.
Ghacks Technology News | Opera 11 Beta Available, Download It Now | Discussion whether to use Rockmelt or Opera. Let them know what you think!
MyADSL | Opera 11 beta released | Interesting forum discussion!
Digit | Opera 11 Beta available; Brings extensions and tab groups | No comments yet! You can be the first.
Erictric | Opera 11 Beta Now Available | There are no comments posted yet. Be the first one!
EFYTimes (press release) | First Beta Of Opera 11 Showcases Tab Stacking | No discussion started.
PC Advisor | Opera 11 Beta available to download | No comments yet.
reddit | Opera 11 Beta out, with tab stacking, visual mouse gestures, and extensions | There's always a discussion on reddit!
Neowin.net | Opera 11 beta released | A lot of comments!
Softpedia | Download Opera 11 Beta, Now with Innovative Tab Stacking | No comments yet!
Techie Buzz | Opera 11 Beta Released: Introduces Tab Stacking and more | No responses so far. Why not write a comment about his article?
Tech Ticker | Opera releases Opera 11 Beta | Waiting for comments!
FindMySoft | Opera 11 Goes Beta, Has Cool New Features | No comments yet!
ComputerworldUK | Title | One comment about mouse gestures.
Tech Hamlet | Download Opera 11 Beta 1 Now! | Still waiting for comments.
FavBrowser | Download Opera 11 Beta | Discussion started.
Lifehacker | Opera 11 Beta Introduces Tab Stacking for Customized Grouping | No comments.

37 comments

1 2 3 4 5 ... 104 Next »

## Choose Opera

Join this group